%pile_interaction
function [Brinch_Hansen] = Brinch_Hansen_plastic_force(pile_input, pile_output)
    for pile = 1:length(pile_input)
        phi_array = pile_output(pile).discrete_soil_info.phi; 
        dz = pile_output(pile).grid.dz;
        grid_z = pile_output(pile).grid.z;
        depth_array = pile_output(pile).grid.z - pile_input(pile).top_pile; 
        D = pile_input(pile).D;
        effective_weight = pile_output(pile).discrete_soil_info.effective_weight;
        effective_stress = 0 ;
        for i = 1:length(phi_array)
            [KD_q,KD_c] = BH_Function(D,depth_array(i),phi_array(i));
            Brinch_Hansen(pile).KD_q(:,2) = grid_z;
            Brinch_Hansen(pile).KD_c(:,2) = grid_z;
            Brinch_Hansen(pile).KD_q(:,3) = depth_array;
            Brinch_Hansen(pile).KD_c(:,3) = depth_array;
            Brinch_Hansen(pile).KD_q(i,1) = KD_q;
            Brinch_Hansen(pile).KD_c(i,1) = KD_c;
        end 

    %% effective stress per depth 
        for i = 1:length(effective_weight)
            effective_stress = dz*effective_weight(i) + effective_stress ;
            Brinch_Hansen(pile).effective_stress(i+1,1) = effective_stress  ; 
        end
            Brinch_Hansen(pile).effective_stress(1,1) = 0 ;   
    %% Brinch Hansen force _ no correction factors 
        effective_stress = Brinch_Hansen(pile).effective_stress;
        KD_q = Brinch_Hansen(pile).KD_q(:,1);
        KD_c = Brinch_Hansen(pile).KD_c(:,1);
        cohesion = pile_output(pile).discrete_soil_info.cohesion;
        cohesion = [cohesion', cohesion(end)]';
        Brinch_Hansen(pile).Cohesion = cohesion;
        
        %% weight factor W_F + cohesion factor W_C 
        W_F = pile_output(pile).BH_factors.weigthfactor ; 
        C_F = pile_output(pile).BH_factors.cohesionfactor ;  
        W_F = [W_F',W_F(end)]'; 
        C_F = [C_F',C_F(end)]'; 
        
        %% deeper than L/2 use a factor 0.5 (doesnt matter at this depth, it will react elastic not plastic)
        half = round(length(W_F)/2);
        W_F(half:end) = 0.5;
        C_F(half:end) = 0.5; 
%         no_correction = 0.5.*ones(half,1); 
%         W_F = [W_F(1:half-1); no_correction]; 
%         C_F = [C_F(1:half-1); no_correction]; 

        %%
        length(cohesion); 

        eD = effective_stress.*KD_q .*W_F+ cohesion.*KD_c .*C_F ; 
        qeD = eD.*D;
        % if the reduction becomes that large it is unrealistic. Becomes
        % therefore a minimum pressure of 10 was maintained
        
        for i = 1:length(qeD)
        if qeD(i) < 3 
            qeD(i)  = 10; 
        end 
        end 
        
        Brinch_Hansen(pile).Force_correction = qeD ;  
        eD_nc = effective_stress.*KD_q + cohesion.*KD_c  ; 
        qeD_no_correction = eD_nc.*D; 
        Brinch_Hansen(pile).Force_no_correction = qeD_no_correction ;   
    end
end 
