%The provided code is made available as open access, and all credits and recognition for its creation go to 
%Mart-Jan Hemel, the original author. This code is provided here for educational and illustrative purposes, 
%and any use or further distribution should be attributed to Mart-Jan Hemel. 
%% SECTION A: Input of quay wall parameters
% First an imput structure is created which contains all input information 
% of the quay wall structure. The corresponding file can be found in "Input_window.m". 
clear all; close all; warning('off') %avoid warnings 
[pile_input,quay_input] = input_window();
%% SECTION B: Pile wedge (no interaction and flat surface) 
%In here the wedge of each pile is determined based on the corresponding
%soil conditions. The function which creates a pile wedge can be found
%under functions "pilefact.m". The pile wedges do not take into account
%slope, side and front hiding. 

n_piles = length(pile_input);
for pile = 1:n_piles   
    [pile_output(pile)] = pilefact(pile_input(pile),pile);
end  
% PLOTS FOR FREE DEVELOPING WEDGE. 
%FIX PLASTIC DEPTH FOR THESE PLOTS IN input_window
PLT.pileOI2D = 2;  %Pile of interest

%plot on/off?? type 1 for on, 0 for 'off'
PLT.TDwedgeplot = 0; %for depth section plots
PLT.D3wedgeplot = 0; %for 3D plot

%% SECTION C: Pile wedge interaction correction (interaction + slope)
% The piles are cropped based on the surrounding piles and the slope. The
% cropping takes into account side hiding, front hiding and slope.
% Corresponding function is named "pile_interaction". Based on the cropped
% pile wedges, Brinch Hansen correction factors are determined. These
% factors are based on the weight of each slide plane and the cohesion
% between the slide planes. 

[pile_output] = pile_interaction(pile_output,pile_input); 

%FIX PLASTIC DEPTH FOR THESE PLOTS IN input_window
%plot on/off?? type 1 for on, 0 for 'off'
PLT.cropwedgeplot = 0 ;  %for 3D plot cropped piles

% Functions for for wedge visulaization
% plots are all out now. these plot are just for visualization purposes
Pile_interaction_plot2D3D(pile_input,pile_output,PLT) 
cropped_pile(pile_input,pile_output,PLT)      
%% SECTION D: Brinch Hansen plastic force 
% Based on the plastic height of each pile, which is defined in the pile
% input, a corresponding plastic force is computed. The plastic force is
% determined with Brinch Hansen for discrete depths. The correction factors are applied to
% Brinch Hansen so that pile interaction and slope are taken into account.  

[Brinch_Hansen] = Brinch_Hansen_plastic_force(pile_input, pile_output);

% Brinch Hansen plastic functions (as function of depth) 

% The  Brinch hansen plastic force (at discrete depth locations) is
% interpolated to form continues functions. These will be used in the quay
% wall beam model in which the functions are the plastic loads on the top
% section of the piles. 

[Brinch_Hansen] = BH_interpolation(pile_input,pile_output,Brinch_Hansen); % BH_interpolation = Brinch Hansen Interpolation

% Brinch Hanssen plot
%plot on/off?? type 1 for on, 0 for 'off'
PLT.BHfactorplot  = 0; % Brinch Hanssen reduction factors
PLT.BH_forceplot = 0; % Brinch Hanssen plastic force plot

%plot functions
BH_plot(pile_input,pile_output,PLT)    %    
BH_polyfunction(pile_input,pile_output, Brinch_Hansen,PLT)
%% SECTION E: Menard springs 
% The Menard springs for each pile are determined. 
[Menard] = Menard_Function(pile_input);

%% SECTION F: Flamant soil stress model
% In this module, the superposition of stress fields is computed to obtain
% the total effective vertical stress field in the active domain of the quay.
onoff_flamant = 1;  % 0 off, 1 on; %If ON, stress field behind the quay will be plotted with stresses at the 4 boundaries in the domain.
[load_vector, phi_average_wall ,phi_average_sheetpile,Segment_friction] = Flamant(pile_input,quay_input,onoff_flamant);

%% SECTION G: Compute loads on quay wall 
% In this module, the forces on the quay are computed from the stress field
% by integration and multiplication with K factors.
[loads] = Forces_on_quay(pile_input,quay_input,load_vector, phi_average_wall ,phi_average_sheetpile,Segment_friction);

%% SECTION H: Iteration file creator

q_dist_load=loads.q_dist_load;  

%lineaire load opbouw, voorste paal 0%
perc = 1:1:n_piles; 
perc_nominal = perc/sum(perc);
q_dist_load_array = perc_nominal.*q_dist_load;  % load from sheetpile

iteration = struct; 
k_max = 2; 
%create general structure for each pile 

for pile = 1:length(pile_input)
    outstuck_pile  = 1; %there is an outstuck, 
    if pile_input(pile).levels.floorlevel == pile_input(pile).top_pile
        outstuck_pile = 0; %no outstuck 
    end 
    iteration(pile).input.floor = pile_input(pile).levels.floorlevel;
    iteration(pile).input.EI = pile_input(pile).structural_properties_EI_pile;  

    iteration(pile).y_values = Menard(pile).discrete_steps; %values in the soil, not the top
    iteration(pile).out_stuck = outstuck_pile;
    iteration(pile).number_of_layers = size(iteration(pile).y_values,2)-1;
    q = cell(1,iteration(pile).number_of_layers); 
    for i = 1:iteration(pile).number_of_layers 
        q{i} = @(y) 0; 
    end
    iteration(pile).plastic_load =  q; 
    iteration(pile).spring   = [Menard(pile).discrete_springs'] ;
    iteration(pile).spring_0   = [Menard(pile).discrete_springs'] ;

    iteration(pile).initial_matrix = zeros(length(iteration(pile).y_values),3);
    iteration(pile).initial_matrix(:,1)= iteration(pile).y_values; 
    iteration(pile).initial_matrix(1,2) = NaN; 
    iteration(pile).initial_interval = Brinch_Hansen(pile).intervals;
    

    for i = 1:iteration(pile).number_of_layers 
        if (pile_input(pile).levels.tip_sheet > iteration(pile).y_values(i)) && ( pile_input(pile).levels.mid_sheet <=iteration(pile).y_values(i))
        iteration(pile).sheet_force(i) = q_dist_load_array(pile); 
        else 
        iteration(pile).sheet_force(i) = 0; 
        end
        
    end
  
    %in case of an out_stuck the "free part" of the pile needs to be put in the
    %input arrays as well. 
    %double if loop because, the free end can be loaded by sheet pile
    %forces... 
        
    if iteration(pile).out_stuck == 1
        
        if pile_input(pile).levels.mid_sheet < pile_input(pile).top_pile  %dan moet ie dus in twee gesplitst worden met als splitsing mid_sheet
        
                    
            iteration(pile).spring  = [k_max k_max iteration(pile).spring]; 
            iteration(pile).spring_0  = [k_max k_max iteration(pile).spring_0]; 
            iteration(pile).y_values = [ iteration(pile).input.floor, pile_input(pile).levels.mid_sheet,  iteration(pile).y_values]; 
            iteration(pile).number_of_layers =  iteration(pile).number_of_layers + 2; 
            q = cell(1,iteration(pile).number_of_layers); 
            for i = 1:iteration(pile).number_of_layers 
                q{i} = @(y) 0; 
            end
            iteration(pile).plastic_load =  q; 
            iteration(pile).sheet_force = [ 0, q_dist_load_array(pile),  iteration(pile).sheet_force ]; 

        else 
            
            iteration(pile).spring  = [k_max iteration(pile).spring]; 
            iteration(pile).spring_0  = [k_max iteration(pile).spring_0]; 
            iteration(pile).y_values = [ iteration(pile).input.floor, iteration(pile).y_values]; 
            iteration(pile).number_of_layers =  iteration(pile).number_of_layers + 1; 
            q = cell(1,iteration(pile).number_of_layers); 
            for i = 1:iteration(pile).number_of_layers 
                q{i} = @(y) 0; 
            end
            iteration(pile).plastic_load =  q; 
            iteration(pile).sheet_force = [ 0 iteration(pile).sheet_force ]; 
        end 
        
    end 
    
    iteration(pile).Normal_force = 0;
    iteration(pile).shear_force_pilehead = 0;
    iteration(pile).rotation_pilehead = 0;
end
    %% SECTION I: 1st iteration, fully elastic computation

    [w_d, w_p, phi_d, phi_p, M_d, M_p, V_d, V_p,X,Y,Normal_force,Shear_force,Phi_pile,V_tangent] = beamcalc(iteration, pile_input,loads,quay_input);

%% SECTION J: nth iteration, elastic - plastic computation. 
max_number_of_itterations = 10;
for itte = 1:max_number_of_itterations
    disp(['Iteration ',num2str(itte)])
    [iteration] = stress_iteration(Brinch_Hansen,Menard,iteration,w_p,pile_input,Normal_force,Shear_force,Phi_pile,q_dist_load_array);
    [w_d, w_p, phi_d, phi_p, M_d, M_p, V_d, V_p,X,Y,Normal_force,Shear_force,Phi_pile,V_tangent] = beamcalc(iteration, pile_input,loads,quay_input);
    n_piles = length(iteration);
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%if system is stable, break out of the itteration loop%%%%% %also%%%%%
    %%%repetitions are taken care of%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    paalteller = 0;
    for j = 1:n_piles
           
        Count_cell{j}(itte) = iteration(j);
        STOP = 0; 
        if itte > 1 
            A =  Count_cell{j}(itte).new_matrix; 
            A(isnan(A))=0;
            for rep = 1:itte-1
                B =  Count_cell{j}(rep).new_matrix; 
                B(isnan(B))=0;
                tf = isequal(A,B); 
                if tf == 1   
                    STOP = 1;  
                end 
            end 
        end
        if STOP == 1 
            paalteller = paalteller + 1; 
            disp(['Pile ',num2str(j),' stable' ])
        end
        
        if itte == max_number_of_itterations
            disp(['System is not stable after ',num2str(itte),' iterations' ])
        end 
        
    end
    
    if paalteller == n_piles %stability for all piles
            disp(['Computation completed. Number of iterations = ',num2str(itte)])
        break 
    end 

end 
%% SECTION K: Storage of output ( just a selection)
% Moments 
maximal_M = zeros(n_piles,1);

for j = 1:n_piles
moments = [];
depth  = [];

for i = 1:length(Y{j})-1
    [z,M] = fplot(M_p{j}(i),[Y{j}(i) Y{j}(i+1)]);
     moments = [moments,M];
     depth = [depth,z];
end


moment_array{j}= {moments}; 
depth_array(j) = {depth}; 

maximal_M(j) = max(max(moments), max(-1*moments));
end 
MaxMoment = maximal_M;
[x,w] = fplot(w_p{1}(1),[pile_input(1).levels.floorlevel ,pile_input(1).levels.floorlevel]);
w_group = w; 
cap_force = [];
for i = 1:n_piles
    [x,Vcap] = fplot(V_p{i}(1),[pile_input(1).levels.floorlevel ,pile_input(1).levels.floorlevel]);
     cap_force = [cap_force,Vcap];
end
cap_phi = [];
% for example a cap level of 1.7
cap_level = 1.7;
for i = 1:n_piles
    [x,Phicap] = fplot(phi_p{i}(1),[cap_level cap_level]); %LET OP 3 IS USED = 0.2m below cap because of sensor lay out.
     cap_phi = [cap_phi,Phicap];
end
%% SECTION L: OUTPUT; W, M, V, Phi, Sigma
% 1 = ON, 0 = OFF
WPLOT = 1; % deflection plots
MPLOT = 1; % bending moment plots
VPLOT = 1; % shear force plots
PHIPLOT = 1; % rotation (Phi) plots
SIGMAPLOT = 1; % stress (Sigma) plots
Plot_Quay %  plotting program. 
%To speed up computations, use larger dz grid size and put all plots OFF
%% output examples 
maxMoment = max(MaxMoment);%kNm 
deflection = w_group; %m

disp(['The provided code is made available as open access, and all credits and recognition for its creation go to Mart-Jan Hemel, the original author. This code is provided here for educational and illustrative purposes, and any use or further distribution should be attributed to Mart-Jan Hemel. If you find this code useful or have any questions, please consider reaching out to the original author for more information and guidance.'])
