function [Menard] = Menard_Function(pile_input)
    %% soil qualification 

    condition  = {'over_consolidated';'normally_consolidated';'decomposed';'pressiometric_modulus'};
    peat = [0;1;0;3.5]; 
    clay = [1;2/3;1/2;2.5]; 
    loam = [2/3;1/2;1/2;1.5];
    sand = [1/2;1/3;1/3;0.85];
    gravel = [1/3;1/4;1/4;0.6];
    Table = table(peat,clay,loam,sand,gravel,...
        'RowNames',condition); 

    %% Import parameters 
    n_piles = size(pile_input,2);
    n_layers = zeros(n_piles,1); 
    top_piles = zeros(n_piles,1); 
    floor_level = zeros(n_piles,1); 
    pile_length = zeros(n_piles,1); 
    plastic_zones = zeros(n_piles,1); 
    for i = 1:n_piles 
        n_layers(i) = size(pile_input(i).layers,1)-1;
        top_piles(i) = pile_input(i).top_pile;
        floor_level(i) = pile_input(i).levels.floorlevel;
        pile_depth(i) = pile_input(i).levels.pile_tip;
        pile_length(i) = pile_input(i).pile_length; 
        plastic_zones(i) = pile_input(i).plastic_zone;  
    end 

    %% k_h for each layer pro pile 
    Sk_h = struct([]); 
    for pile = 1:n_piles
        k_h =zeros(n_layers(pile)); 
        alpha_coef = zeros(n_layers(pile),1);
        E_m =zeros(n_layers(pile),1); 
        for kwali = 1:n_layers(pile) 
            rheological_coef =  Table(pile_input(pile).qualification(kwali,2),cell2mat(pile_input(pile).qualification(kwali,1)));
            rheological_coef = table2array(rheological_coef); 
            alpha_coef(kwali,1)  = rheological_coef;
            pressimetric_m = Table('pressiometric_modulus',cell2mat(pile_input(pile).qualification(kwali,1)));
            pressimetric_m = table2array(pressimetric_m); 
            E_m(kwali,1)  = pressimetric_m*cell2mat(pile_input(pile).qualification(kwali,3));
        end 
        for kwali = 1:n_layers(pile) 
            R_0 = 0.3;
            R = pile_input(pile).D/2; 
            if R >= R_0
                k_h(kwali,1)= 1/(1/(3*E_m(kwali))*(1.3*R_0*(2.65*R/R_0)^alpha_coef(kwali)+ alpha_coef(kwali)*R));
            else
                k_h(kwali,1)= 1/(2*R/E_m(kwali)*(4*2.65^alpha_coef(kwali)+3*alpha_coef(kwali))/18);
            end 
        end 
        Sk_h(pile).k_h = k_h*pile_input(pile).D;
%         vpa(k_h)
    end 
    %% give each pile their own customized springs per layer

%     free_length = top_piles -  floor_level ;
%     spring_length = pile_length' - plastic_zones' - free_length;
%     start_springs = top_piles + plastic_zones'; 
%     pile_depth = floor_level + pile_length;
   
    for pile = 1:n_piles
        if pile_input(pile).layers(end,1)< max(pile_depth)
            fprintf(2,'ERROR, Pile is deeper than specified soil layers. ')
            return 
        end 
    end 

    layer_counter = ones(1,n_piles);
    start_layer = zeros(1,n_piles); 
    %spring_layers = 
    for pile = 1:n_piles
        for layer = 1:n_layers(pile)
            depth_layer = pile_input(pile).layers(1+layer,1);
            if  top_piles(pile)  < depth_layer && depth_layer < pile_depth(pile)
                layer_counter(pile) = layer_counter(pile) + 1;
            else 
            end 
        end
    end 
    for pile = 1:n_piles
        for layer = 1:n_layers(pile)
            depth_layer = pile_input(pile).layers(1+layer,1);
            if top_piles(pile) < depth_layer
                start_layer(pile) = layer;
                break
            end 
        end
    end 

    for pile = 1:n_piles
        pile_discrete = zeros(1,layer_counter(pile)+2);
        for lay = 1: layer_counter(pile)
            pile_discrete(1) = floor_level(pile);
            pile_discrete(2) = top_piles(pile);
            pile_discrete(lay+2) = pile_input(pile).layers(start_layer(pile)+lay,1);
            pile_discrete(end) = pile_depth(pile);
        end 

        Menard(pile).discrete_steps = pile_discrete(2:end);
    end 

    for pile = 1:n_piles
        Menard(pile).discrete_springs = Sk_h(pile).k_h(start_layer(pile):start_layer(pile)+layer_counter(pile)-1)';
%         Menard(pile).discrete_springs
    end     
        

end 