%% Beam calculation function 
function [w_d, w_p, phi_d, phi_p, M_d, M_p, V_d, V_p,X,Y,Normal_force,Shear_force,Phi_pile,V_tangent] = beamcalc(iteration, pile_input,loads,quay_input) 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%naming the elements of the beam model%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% n = number of piles, p stands for pile,  d stands for deck, C are integration constants
% n+1           n+2                2*n
% w_d(1)        w_d{2}([1,2])             w_d{n}    
% C{n+1}(1-4)   C{n+2}(1-4*2)        C{2*n}(1-4)  constants to be solved 
%__________________/________________________________
%______| |________/____________| |________________| |
%      | | part1 / part 2      | |                | |
%      | |                     | |                | |
%      | |  1                  | | 2              | |  n
%      | |                     | |                | |
%      | | w_p{1}              | | w_p{2}         | |  w_p{n} 
%      | | C{1}(1-4*n_l)       | | C{2}(1-4*n_l)  | |  C{n}(1-4*n_l            
%      | |                     | |                | |  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%Integration constants %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

n_piles = length(iteration);
n_beams = n_piles ; 
C  = cell(n_piles+n_beams,1);

for j = 1:n_piles
    n_l = iteration(j).number_of_layers; 
    C{j} = sym(['C', num2str(j)], [1 4*n_l]);
end     

for j = 1:n_beams
    C{j+n_piles} = sym(['C', num2str(j+n_piles)], [1 4]);
end     
C{n_piles+2} = sym(['C', num2str(n_piles+2)], [1 8]); %second deck consist of two parts

%equations + x and y syms
eq = {}; % create ampty cell for all equations that are created. eq{construction_element}(numberbering) Is also valid for C{i}(i)
syms  y   
syms  x

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%         
%%%%%%%%%%%Create variables for each pile%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%input variables for k, alpha,beta, lambda, delta, y_levels
alpha   = cell(n_piles,1); 
beta    = cell(n_piles,1); 
Y       = cell(n_piles,1); 
K       = cell(n_piles,1); 

for j = 1:n_piles    
    
%%%%%%%%%%%%%%%import parameters%%%%%%%%%%%%%
    spring = iteration(j).spring; 
    y_values = iteration(j).y_values;
    
    n_l = iteration(j).number_of_layers;
    EI_p = iteration(j).input.EI;
    normalN =iteration(j).Normal_force;   %
        
    K{j} = spring ;
    Y{j} = y_values; 
    lambda =  (subs(K{j})./(4*EI_p)).^0.25 ;
    delta  =   normalN/(4*EI_p);
    alpha{j} = sqrt(lambda.^2+delta);
    beta{j} =  sqrt(lambda.^2-delta);
end 

%import the loads %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    V_deck= loads.V_deck  ;
    f_wall=loads.f_wall ;
    force_on_top_deck= loads.force_on_top_deck  ;    
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%rotation springs pile headstock connection
M_res = zeros(1,n_piles);
for i = 1:n_piles
    [M_rot] = ROT_FUNC(quay_input,iteration(i).Normal_force ,iteration(i).shear_force_pilehead ,iteration(i).rotation_pilehead );
    M_res(i) = M_rot; %No pile-headstock connection
end 
sheet_force = V_deck;% force sheetpile on floor 
Deck_load = force_on_top_deck;
EI_d = quay_input.EI_kesp; 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%         
%%%%%%%%%%%Create variables for each deck beam%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
width_block = quay_input.width_block;% 
start_block = -quay_input.overhang_block;%
X = [pile_input(:).x_coordinate]; 
X = [start_block X(1) start_block+width_block X(2:end)];
%%BBBBBBBBBBBBBBBBBBBBBBBB    B = block 
%x1____________x2_______x3_____________x4___________________________X
%              | |      //            | |
%               pile                   pile 
%% equations for w,phi,M,V for a beam supported by springs and loaded by q(x) -> max 3th polinominal function

%piles                       %deck 
w_p =   cell(n_piles,1);     w_d =   cell(n_beams,1);
phi_p = cell(n_piles,1);     phi_d = cell(n_beams,1); 
M_p =   cell(n_piles,1);     M_d =   cell(n_beams,1);
V_p =   cell(n_piles,1);     V_d =   cell(n_beams,1);

% w,phi,M, V for piles
for j = 1:n_piles   

    q = iteration(j).plastic_load;
    n_l = iteration(j).number_of_layers;
    EI_p = iteration(j).input.EI;
    q_sheet = iteration(j).sheet_force ; %

    for i = 1:n_l  
%         GENERATE A PARTICULAR SOLUTION FOR EACH PART 
        syms y
        %a*w''''(z) + bw''(z) + cw(z) = dz^2 + ez + f 
        aa = EI_p;
        bb = iteration(j).Normal_force;
        cc = K{j}(i);
        if q{i}(y) == 0
            [vector] = [ 0 ;0; 0] ;
        else 
            [vector] = coeffs(q{i}(y), 'All')';
        end  
%         vector
        dd = vector(1);
        ee = vector(2);
        ff = vector(3);

        q_part = -dd*y^2/cc - ee*y/cc -ff/cc + 2*bb*dd/(cc^2); 

        w_p{j}(i)   =  C{j}(i*4-3)*exp((y*sqrt(-sqrt(bb^2-4*aa*cc)/aa-bb/aa))/sqrt(2)) +...
                       C{j}(i*4-2)*exp(-(y*sqrt(-sqrt(bb^2-4*aa*cc)/aa-bb/aa))/sqrt(2))+...
                       C{j}(i*4-1)*exp((y*sqrt(sqrt(bb^2-4*aa*cc)/aa-bb/aa))/sqrt(2))  +...
                       C{j}(i*4-0)*exp(-(y*sqrt(sqrt(bb^2-4*aa*cc)/aa-bb/aa))/sqrt(2)) +...
                       q_part + q_sheet(i)/cc;% 
                       
        phi_p{j}(i)  =     -diff(w_p{j}(i),y);                                  
        M_p{j}(i)    =     EI_p*diff(phi_p{j}(i),y);                                                   
        V_p{j}(i)    =     diff(M_p{j}(i),y);%-diff(w_p{j}(i),y)*iteration(j).Normal_force;                               
    end
end

% w,phi,M, V for decks 
for j = 1:n_beams  
    if j == 1 || j == 2 
        q_d = f_wall;
    else
        q_d = Deck_load;
    end 
    
    % there are no layers for the decks accept for , please note, deflection in direction x                                                                 
%     1/EI_d*int(int(int(int(q_d,x))))
    w_d{j}(1)    =     C{j+n_piles}(1)+C{j+n_piles}(2)*x+C{j+n_piles}(3)*x^2+C{j+n_piles}(4)*x^3 + 1/EI_d*int(int(int(int(q_d,x)))); 
    phi_d{j}(1)  =     -diff(w_d{j}(1),x);                                  
    M_d{j}(1)    =     EI_d*diff(phi_d{j}(1),x) ;                                                  
    V_d{j}(1)    =     diff(M_d{j}(1),x);         
    
    %second deck is split into two so needs extra equations (8 constants to be solved) 
    if j == 2 %this is always element 5, the second deck element 
        w_d{j}(2)    =     C{j+n_piles}(5)+C{j+n_piles}(6)*x+C{j+n_piles}(7)*x^2+C{j+n_piles}(8)*x^3 + 1/EI_d*int(int(int(int(Deck_load,x)))); 
        phi_d{j}(2)  =     -diff(w_d{j}(2),x);                                  
        M_d{j}(2)    =     EI_d*diff(phi_d{j}(2),x);                                                  
        V_d{j}(2)    =     diff(M_d{j}(2),x);    
    end 
end

    %% conditions
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%pile conditions%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%NOT INCLUDING CONNECTION WITH DECK%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for j = 1:n_piles     
n_l = iteration(j).number_of_layers;     
% Interface conditions at y = yi i = 2,3...n_l     
    for i = 1:n_l-1
        y = Y{j}(i+1); 
        eq{j}(i*4-3) = subs(w_p{j}(i)   == w_p{j}(i+1));
        eq{j}(i*4-2) = subs(phi_p{j}(i) == phi_p{j}(i+1));
        eq{j}(i*4-1) = subs(M_p{j}(i)   == M_p{j}(i+1));
        eq{j}(i*4  ) = subs(V_p{j}(i)   == V_p{j}(i+1)) ; 
    end
    
% Boundary conditions at y = pile:tip   
    y = Y{j}(end);
    eq{j}(4*n_l-3) = subs(M_p{j}(n_l) == 0);
    eq{j}(4*n_l-2) = subs(V_p{j}(n_l) == 0);    
end 
%%%%%%%%%%%%%%%%%%%%%%%%%%%deck conditions%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%INCLUDING CONNECTION WITH DECK%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
X_con = X([2,4:n_piles+2]); % pile_locations
%first the three connections  
n_3way_connections = n_beams-1; 
y = Y{1}(1); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% no moment and no shear at the tip beams on the water side
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

x = X(1); 
eq{n_piles+1}(1) =  subs(M_d{1}==0);%%%A%A
eq{n_piles+1}(2) =  subs(V_d{1}==0);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% w = 0 (voor alle palen), niet voor het tussenstuk van het tweede deck element
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for i = 1:n_piles %
    x = X_con(i); 
    deck_sectie = 1; 
    if i == 2
        deck_sectie  = 2; 
    end 
    eq{n_piles+2}(i) = subs(w_d{i}(deck_sectie) == 0); %dx voor de paal voor elk dek 
end
for i = 1:n_piles-1  %dx na de paal voor elk dek, de laatste paal heeft geen stukje dx na de paal 
    x = X_con(i); 
    eq{n_piles+2}(i+n_piles) = subs(w_d{i+1}(1) == 0); %dx na de paal voor elk dek 
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% transition conditions W_d2 between section 1 en 2 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
x = X(3); % at intersection
eq{n_piles+3}(1) = subs(w_d{2}(1)    == w_d{2}(2)); 
eq{n_piles+3}(2) = subs(phi_d{2}(1)  == phi_d{2}(2)); 
eq{n_piles+3}(3) = subs(M_d{2}(1)    == M_d{2}(2)); 
eq{n_piles+3}(4) = subs(V_d{2}(1)    == V_d{2}(2)); 



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% phi left of pile = phi right of pile
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for i = 1:n_piles-1
    x = X_con(i);
    deck_sectie = 1; 
    if i == 2
        deck_sectie  = 2; 
    end 
    eq{n_piles+4}(i) = subs(phi_d{i}(deck_sectie)== phi_d{i+1}(1)); 
end 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  % y = 0; x = x1,x2,...xn-1; ->>> M1+M2 = M3 (continues beam)+
%  change in phi
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for i = 1:n_piles-1
    x = X_con(i);
    deck_sectie = 1; 
    if i == 2
        deck_sectie  = 2; 
    end 

    eq{n_piles+5}(i) = subs(M_d{i}(deck_sectie) - M_d{i+1}(1) == M_p{i}(1));
    eq{n_piles+5}(i+n_piles-1) = subs(M_p{i}(1) == M_res(i));  
end 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  % y = 0; xn; ->>> M1 = M3 (corner connection  )+ difference in phi
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
x = X_con(end); 
% als er maar 2 palen zijn dan moet het  gesplitste deel de rechter kant
% nemen. dan is het dus deel 2 van de gesplitste ligger. Met meer palen is het
% gewoon 1 dek ligger en dus index 1
if n_beams ==2 
    eq{n_piles+6}(1) = subs( M_d{n_beams}(2) == M_p{n_piles}(1)) ;
    eq{n_piles+6}(2) = subs( M_d{n_beams}(2) == M_res(n_beams)); 
else
    eq{n_piles+6}(1) = subs( M_d{n_beams}(1) == M_p{n_piles}(1)) ;
    eq{n_piles+6}(2)  = subs(M_p{n_beams}(1) == M_res(n_beams)); 
end 


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  % y = 0; x; ->>> shearforce of the pile caps = total horizontal loading
%  on deck 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
index_piles = 1:1:n_piles; 
a_1 = 0; 
for i = 1:n_piles
    a_1 = subs(V_p{i}(1)+ phi_p{i}(1)*iteration(i).Normal_force+a_1); 
end 
eq{n_piles+7}(1) =  subs(a_1 == -sheet_force ); 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  % y = 0; x; ->>> w for all piles is the same
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for i = 1:n_piles-1
    eq{n_piles+8}(i) =  subs(w_p{1}(1) ==  w_p{i+1}(1)); 
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%create one big equation array eq = [eq{} + eq{} + eq{}] 
EQ = {};
C_tot  = {};
C_var  = {};
for i = 1:length(eq)
    EQ = [EQ, eq{i}]; 
end 


for i = 1:length(C)
    C_tot = [C_tot, C{i}];
    C_var = [C_var, C{i}];
end 

% From matrix A and force vector b-> solve Ax = b with x = C1,C2...Cn
     y = 'y'; 
     x = 'x'; 

     
[A,b] = equationsToMatrix(eq, C_tot); 

Asub =vpa(A,1000);
bsub = vpa(b,1000);  
C_tot = Asub\bsub ;

% give all Constants their corresponding value and substitude them back in
% the equations w,phi,M,V for all piles and all beams
for k = 1:numel( C_var)
    eval(sprintf('%s=C_tot(%d);',char( C_var(k)),k));
end
%%
for j = 1:n_piles   

    n_l = iteration(j).number_of_layers;
    for i = 1:n_l                                                                
         w_p{j}(i)      = real(subs(w_p{j}(i)))     ;
         phi_p{j}(i)    = real(subs(phi_p{j}(i)))   ;                        
         M_p{j}(i)      = real(subs(M_p{j}(i)))     ;                                              
         V_p{j}(i)      = real(subs(V_p{j}(i)))     ;                            
    end
end

for j = 1:n_beams                                                           
    
     w_d{j}(1)          = real(subs(w_d{j}(1)))         ;
     phi_d{j}(1)        = real(subs(phi_d{j}(1)))       ;          
     M_d{j}(1)          = real(subs(M_d{j}(1)))         ;                                         
     V_d{j}(1)          = real(subs(V_d{j}(1)))         ;  
 
    %second deck is split into two so needs extra equations (8 constants to be solved) 
    if j == 2 %this is always element 5, the second deck element 
         w_d{j}(2)      = real(subs(w_d{j}(2)))       ;
         phi_d{j}(2)    = real(subs(phi_d{j}(2)))     ;                        
         M_d{j}(2)      = real(subs(M_d{j}(2)))       ;                                              
         V_d{j}(2)      = real(subs(V_d{j}(2)))       ;
    end 
    
end
 
% collection of the normal force, pile shear forces and pile head rotations
%for 2nd order and pile headstock connection.
Normal_force = zeros(1,n_piles);
phi_kesp = zeros(1,n_piles);
for j = 1:n_beams-1 %last pile is just 1 shear   
    x = X_con(j);

    if j == 2
        Shear_left = subs(V_d{j}(2)) ;
        Shear_right = subs(V_d{j+1}(1)) ;
        phi_kesp(j) = subs(phi_d{j}(2)) ;
    else
        Shear_left = subs(V_d{j}(1)) ;
        Shear_right = subs(V_d{j+1}(1)) ;  
        phi_kesp(j)  = subs(phi_d{j}(1)) ;
    end 
    
    Normal_force(j) = (Shear_right-Shear_left) ;
end    
    x = X_con(end); %last pile
    if n_beams == 2 
        Normal_force(n_piles) = -subs(V_d{n_piles}(2)) ;
        phi_kesp(n_piles) = subs(phi_d{n_piles}(2)) ;
    else 
        Normal_force(n_piles) = -subs(V_d{n_piles}(1)) ;
        phi_kesp(n_piles) = subs(phi_d{n_piles}(1)) ;
    end 
    Shear_force = zeros(1,n_piles);
    Phi_pile = zeros(1,n_piles);
    y = Y{1}(1); 
    for i = 1:n_piles
    Shear_force(i) =  -vpa(subs(V_p{i}(1)));
    Phi_pile(i) =  vpa(subs(phi_p{i}(1)));
    end 
    %difference between headstock rotation and pile rotation is the actual
    %rotation for the ROT_FUNC to determine the stiffness of the
    %pile-headstock connection.
    Phi_pile = Phi_pile-phi_kesp; 

    V_tangent =  Shear_force-Phi_pile.*Normal_force;
%     Normal_force(1:n_piles) = 0; EFFECT OF NORMAL FORCE CAN BE PUT OFF BY EMPLOYING THIS STATEMENT
end
