
function [pile_input,quay_input] = input_window()
%Aanstuurprogramma 
waterlevel = 0.4; %indicated with WL , WRT NAP
soil_surface = -0.7 ; %indicated with SS, WRT NAP
floor_level = 1.4; %% indicated with FL, WRT NAP
%%%%%%%%%%%%%%%%%%%
 %__SS___________________  
        %|      %|
        %|      %|
        %|      %|
 %__WL__%|________________       
        %|      %|
        %|      %|
        %|      %|  
 %__FL__%|______%|________
 %        ________________  
height_wall = floor_level-soil_surface; 
% stiffness and dimensions of the piles
n_piles = 4; % number of piles
factor = 1.0; % tuning parameter for OVERAMSTEL pile stiffnesses
z = 2; % Depth at expected maximal moment wrt pile cap in m
EI = factor*(-81.46*z + 945.77); % found relation from bending exeriments for OVERAMSTEL piles
EI_pile = ones(1,n_piles).*EI;
D = 0.24; %diameter in m
E = 9000*10^3; %kN/m^2
helling = 1/3*ones(n_piles,1); % slope of the soil; possible to vary e.g. [ 0 1/3 1/2 1/2]
top_first_pile = 3.; % bed level of first pile wrt NAP
ctc_piles_x = .85;%round(parameter,1); % parameter; Center to center distance of piles INLINE in m
ctc_piles_y = 1.0;%round(parameter,1); % parameter; Center to center distance of piles SIDE BY SIDE in m
center2center_y = ctc_piles_y*ones(n_piles,1);
dz = 0.2; % grid size of the wedge m
x_coordinates = 0:ctc_piles_x:((n_piles-1)*ctc_piles_x); % 2:4:4*(n_piles-1);
y_coordinates = 0*ones(n_piles,1);
top_piles_in_soil = round([top_first_pile,  top_first_pile - (x_coordinates(2:end)-x_coordinates(1)).*helling(2)],1);  %let op dit is aangepast (2)
top_piles_in_soil = floor(top_piles_in_soil) + ceil( (top_piles_in_soil-floor(top_piles_in_soil))/dz) * dz ;
find_tf = top_piles_in_soil<floor_level; 
top_piles_in_soil(find_tf) = floor_level;
if top_piles_in_soil(end) < floor_level
    fprintf(2,'ERROR: Floor is located below piles. ');
    return
end 
L = 12; %length of the piles in m
pile_length = L.*ones(n_piles,1) ; pile_length = floor(pile_length) + ceil( (pile_length-floor(pile_length))/dz) * dz;
pile_depth = floor_level + pile_length;
pile_depth = floor(pile_depth) + ceil( (pile_depth-floor(pile_depth))/dz) * dz;
plastic_zones =  round([pile_depth-top_piles_in_soil'] ,1) ; 
plastic_zones(plastic_zones==0) = dz; 
%% FOR PLOTS OF WEDGES ENTER HERE THE PLASTIC HEIGHTS PER PILE
% plastic_zones = [3 3 3 3]; %EXAMPLE FOR PLOTS 
%%
% use when EI is not known 
% schil = 0.015; %cm
% Izz = 1/4*pi*((D-schil)/2)^4; %m^4
% EI_pile =  ones(1,n_piles).*E* Izz; 
%% soil profiles around piles
% only 1 profile for all piles, if more are needed, use lagen1, lagen 2,
% lagen 3.. and put them in the structure for each pile seperatly 
% [surface 0 0 0 0; end_of_layer, phi, y, c, y' ; ....,....,...,....,....]

%   end_of_layer,       phi,    y,      c,       y' 
lagen = ...
    [soil_surface       0       0       0       0    ;... 
    waterlevel          32.5   18.      0.1     18.0 ;...
    floor_level         32.5   9.0      0.1     9.0  ;...
    4.0                 0      6.9      30      6.9  ;...
    5.8                 0      0.1      30      0.1  ;...
    6.4                 0      9.1      45      9.1  ;...
    8.4                 34     8.0      0       8.0  ;...
    11.6                0      7.0      50      7.0  ;...
    12.2                0      1.7      0.0     1.7  ;...
    20                  33     9.0      0.0     9.0 ];
lagen(:,1) =  floor(lagen(:,1) ) + ceil( (lagen(:,1) -floor(lagen(:,1) ))/dz) * dz;

qc_layer = {10000, 10000,150, 150, 200, 1000, 400, 1000, 10000};   %average qc per layer 
qualification = {'sand','sand','clay' ,'peat','clay','sand','clay','peat','sand'};  
condition_of_layers = {'normally_consolidated'};  % choose from: 'over_consolidated' 'normally_consolidated' 'decomposed' 

for i = 1:n_piles 
    lagen_array{i} = lagen; 
    qc_layer_array{i} = qc_layer;
    qualification_array{i} = qualification;
end 

%in case layering per pile differs use lagen2.. 3..4 etc

% lagen2 = ...
%     [soil_surface       0       0       0       0       ;... 
%     waterlevel          phi_z   y_z      0.1     y_z      ;...
%     floor_level         phi_z   (y_z-10) 0.1   (y_z-10)  ;...
%     floor_level+3       phi_v   y_v      c_v       y_v       ;...
%     floor_level+11.5    phi_k   7.2     c_k     7.2     ;...
%     floor_level+14      35     10.0    3.7     10.0    ];
% lagen2(:,1) =  floor(lagen2(:,1) ) + ceil( (lagen2(:,1) -floor(lagen2(:,1) ))/dz) * dz;
% qc_layer2 =  {10000 10000 q_v q_k 10000};   %average qc per layer 
% qualification2 = {'sand','sand','peat','clay','sand'};  
% 
% 
% lagen3 = ...
%     [soil_surface       0       0       0       0       ;... 
%     waterlevel          phi_z   y_z      0.1     y_z      ;...
%     floor_level         phi_z   (y_z-10) 0.1   (y_z-10)  ;...
%     floor_level+3       phi_v   y_v      c_v       y_v       ;...
%     floor_level+11.5    phi_k   7.2     c_k     7.2     ;...
%     floor_level+14      35     10.0    3.7     10.0    ];
% lagen3(:,1) =  floor(lagen3(:,1) ) + ceil( (lagen3(:,1) -floor(lagen3(:,1) ))/dz) * dz;
% qc_layer3 =  {10000 10000 q_v q_k 10000};   %average qc per layer 
% qualification3 = {'sand','sand','peat','clay','sand'};  

% lagen(3:end,1) = lagen(3:end,1); 
% lagen2(3:end,1) = lagen2(3:end,1); 
% lagen3(3:end,1) = lagen3(3:end,1); 

% lagen_array = {lagen, lagen2, lagen3};
% qc_layer_array = {qc_layer, qc_layer2, qc_layer3};
% qualification_array = {qualification, qualification2, qualification3 };

%% Sheetpile 
for i = 1:n_piles
lagen = [];
qualification = [];
qc_layer = [];

%input for sheetpile, see sketch below
Eff_sheet = 1/3;  
L_sheet = 5; %length of sheetpile in m
tip_sheetpile = floor_level+L_sheet; % afronden op dz! 

lagen = lagen_array{i};
qc_layer = qc_layer_array{i}; 
qualification = qualification_array{i};

L_sheet = tip_sheetpile - floor_level ;
mid_sheet_level = floor_level+L_sheet*(1-Eff_sheet);
mid_sheet_level = floor(mid_sheet_level) + ceil( (mid_sheet_level-floor(mid_sheet_level))/dz) * dz ;
%ILLUSTRATIVE FIGURE

%                          ------------------floor_level       _
%                    <=   F_d   ||  q(z)                        |
%                               ||  q(z)                        |
%                               ||  q(z)                        |
%                               ||  q(z)                        |
%                          ------------------mid_sheet_level    L_sheet 
%                   <=    q_p   ||  q(z)                        |         -
%                   <=    q_p   ||  q(z)                        |          | 
%                   <=    q_p   ||  q(z)                        |          |
%                   <=    q_p   ||  q(z)                        |     L_sheet*Eff_sheet
%                   <=    q_p   ||  q(z)                        |          |
%                          ------------------tip_sheetpile     _|         -|

%insert sheetpile levels in 'lagen' but keep the same properties, this is
%imporatant for the differential equations because the load of the
%sheetpile will be put on the piles for the section L_SHEET*EFF_SHEET.

mid_sheet_laag = [ mid_sheet_level  1 1 1 1 ];
tip_sheet_laag = [ tip_sheetpile  1 1 1 1 ];

lagen_plus_mid = [lagen; mid_sheet_laag];
lagen_plus_mid  = sortrows(lagen_plus_mid,1);
RowIdxMID = find(ismember(lagen_plus_mid, mid_sheet_laag,'rows'));
lagen_plus_mid(RowIdxMID,2:end) = lagen_plus_mid(RowIdxMID+1,2:end); 

lagen_plus_tip = [lagen_plus_mid; tip_sheet_laag];
lagen_plus_tip  = sortrows(lagen_plus_tip,1);
RowIdxTIP = find(ismember(lagen_plus_tip, tip_sheet_laag,'rows'));
lagen_plus_tip(RowIdxTIP,2:end) = lagen_plus_tip(RowIdxTIP+1,2:end);
lagen =  lagen_plus_tip;

value_qc_tip = qc_layer(RowIdxTIP-2);
value_qc_mid = qc_layer(RowIdxMID-1);
i1 = RowIdxMID-1;
i2 = RowIdxTIP-2;
qc_layer = [qc_layer(1:i2-1),value_qc_tip,qc_layer(i2:end)];
qc_layer = [qc_layer(1:i1-1),value_qc_mid,qc_layer(i1:end)];

value_qual_tip = qualification(RowIdxTIP-2);
value_qual_mid = qualification(RowIdxMID-1);
qualification = [qualification(1:i2-1),value_qual_tip,qualification(i2:end)];
qualification = [qualification(1:i1-1),value_qual_mid,qualification(i1:end)];

%remove doubles from qc_layer, lagen and qualification 

[lagen,ia,ic] = unique(lagen,'rows'); 
ia = ia(2:end) -1; 
qc_layer(ia);
qualification(ia);
lagen(:,1) =  floor(lagen(:,1) ) + ceil( (lagen(:,1) -floor(lagen(:,1) ))/dz) * dz;

lagen_array{i} = lagen ;
qualification_array{i} = qualification ;
qc_layer_array{i} = qc_layer;
end 

%% Put pile and soil information in the input structure
%fold pile_input   
    for pile = 1:n_piles
        pile_input(pile).center2center_y = center2center_y(pile);
        pile_input(pile).helling = helling(pile); 
        pile_input(pile).D = D;
        pile_input(pile).levels.waterlevel = waterlevel;
        pile_input(pile).levels.floorlevel = floor_level;
        pile_input(pile).top_pile = top_piles_in_soil(pile);  
        pile_input(pile).plastic_zone = plastic_zones(pile); 
        pile_input(pile).gridsize_dz = dz;
        pile_input(pile).x_coordinate = x_coordinates(pile);
        pile_input(pile).y_coordinate = y_coordinates(pile);
        pile_input(pile).structural_properties_EI_pile = EI_pile(pile); 
        pile_input(pile).pile_length = pile_length(pile);
        pile_input(pile).levels.pile_tip = pile_depth(pile);
        pile_input(pile).levels.mid_sheet = mid_sheet_level;
        pile_input(pile).levels.tip_sheet = tip_sheetpile;
        
        pile_input(pile).layers = lagen_array{i} ;
        pile_input(pile).qualification(:,1) = qualification_array{i};
        pile_input(pile).qualification(:,2) = condition_of_layers;
        pile_input(pile).qualification(:,3) = qc_layer_array{i} ;
        
    end 
%% QUAY WALL INPUT %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %directly create stucture 
quay_input.height_block = height_wall;
quay_input.overhang_block = 0.2;%m difference between first pile and front of the gravity wall
Verschil_damwand_laatste_paal = 0.3; %% difference sheetpile and last pile row. in m
quay_input.dz = 0.1; %dz for flamant soil stress field, in m
quay_input.surface = soil_surface ;  % soil surface level  in m
quay_input.tip_sheet_pile = tip_sheetpile; % bottom of sheetpile in m
quay_input.difference_deck_end_and_sheetpile = 0; % difference between horizontal sheetpile location and the end of the quay wall floor in m
quay_input.Length_deck = max(x_coordinates)-min(x_coordinates)+quay_input.overhang_block+Verschil_damwand_laatste_paal; %length floor in m
quay_input.width_block = 1; %m width of the gravity wall at the bottom
quay_input.width_block_top = 1;   %m width of the gravity wall at the top 
quay_input.afstand_tot_tip_deck_and_top_load = 2;  %m distance between top load front and sheetpile location
quay_input.weight_block =  22; %kN/m^3 unit weight of the gravity wall

quay_input.Length_sheet = L_sheet; %length sheetpile in m
quay_input.factor_Z_eff = Eff_sheet; 
quay_input.ctc_piles = ctc_piles_y; 
quay_input.h1 = waterlevel- soil_surface; % gravity wall above water level in m
quay_input.h2 = floor_level-waterlevel;  %gravity wall below water level in m

%% SURFACE LOADS and dimensions
quay_input.top_load = 10 ; %TOPLOAD in KPa / kN/m^2 
quay_input.width_top_load = 2.7; %m WIDHT OF TOPLOAD
%2nd load
quay_input.width_top_load2 = 1; %TOPLOAD in KPa / kN/m^2 
quay_input.top_load2  = 0; %m WIDHT OF TOPLOAD
quay_input.afstand_tot_tip_deck_and_top_load2 = 2.7;
%% SOIL LAYERS BEHIND THE QUAY / ACTIVE SOIL BODY LAYERING AND SEGMENTAL FRICTION
lagenbehind = ...
    [soil_surface       0       0        0.0     0    ;... 
    waterlevel          38      15.      0.0     15.0 ;...
    2.0                 38      9.0      0.0     9.0  ;...
    3.8                 30      6.9      0.0     6.9  ;...
    6.0                 30      0.1      0.0     0.1  ;...
    7.0                 28.4    9.1      0.0     9.1  ;...
    8.0                 34      8.0      0.0     8.0  ;...
    12.4                25      5.5      0.0     5.5  ;...
    20                  35      9        0.0     8.9 ];
lagenbehind(:,1) =  round(lagenbehind(:,1),1);
quay_input.lagenbehind = lagenbehind; 

%friction segment 
quay_input.segment_friction_coef = 1/10;
quay_input.Ka_s = 0.28; % ACTIVE COEFFICIENT FOR SEGMENT, compute by hand
quay_input.segment_width = 6.5; %widht of the segment
%% pile headstock connection 
% headstock
h_kesp = .200; %m Height headstock
b_kesp = .250; %m width headstock
E_kesp = E;   %Emodulus of headstock
I_kesp = 1/12*b_kesp*h_kesp^3; %moment of inertia headstock 
EI_kesp = E_kesp*I_kesp; %kN/m^2  Flexural stiffness headstock
quay_input.EI_kesp = EI_kesp; 
quay_input.rotation_spring_input.E  = 320;   %N/mm^2  mean    
quay_input.rotation_spring_input.f_ck_K = 2.3;   %N/mm^2 axial strenght headstock -|
% pin
quay_input.rotation_spring_input.f_bend_pin = 18; %N/mm^2 bending strength pin
quay_input.rotation_spring_input.L_pin   = 100;   %mm height pin (can be same as height kesp..)
quay_input.rotation_spring_input.wp = 100;    %%mm Width of the pin
quay_input.rotation_spring_input.f_ck_P = 2.3;   %N/mm^2 axial strenght of pin -|
quay_input.rotation_spring_input.Dk   = 0.26*1000;    %mm pile diameter at the cap (do not use a soft shell but effective diameter)

end