
%top_pile_in_soil, plastic_zone,x_coordinate_pile,y_coordinate_pile,D,helling
function [pile_output] = pilefact(pile_input,pile)
    
    helling = pile_input.helling;
    D = pile_input.D; 
    top_pile_in_soil = pile_input.top_pile; 
    plastic_zone = pile_input.plastic_zone; 
    waterlevel = pile_input.levels.waterlevel;
    dz = pile_input.gridsize_dz;
    x_coordinate_pile = pile_input.x_coordinate;
    y_coordinate_pile = pile_input.y_coordinate;
    lagen = pile_input.layers;
    top_pile_in_soil = round(top_pile_in_soil,1);
    z = top_pile_in_soil:dz:plastic_zone+top_pile_in_soil;

    n = 2*length(z)+4;                          %matrix size for grid size(n,length(z))
    X = NaN*ones(length(z),n);                  %coordinates for grid X Y Z 
    Y = NaN*ones(length(z),n);
    Z = NaN*ones(length(z),n);
   
    phi = zeros(length(z),1);                   %array in depth for phi 
    px = NaN*ones(length(z),length(z));         %matrix for cross sections x 
    py = NaN*ones(length(z),length(z));         %matrix for cross sections Y 
      
    %Define phi for each dz step 
    for layer = 1:length(lagen(:,1))
        for fourgrids = 1:length(z)
            if  lagen(layer,1) <= z(fourgrids) && z(fourgrids) < lagen(layer+1,1)
                
                phi(fourgrids) = lagen(layer+1,2);
                weight(fourgrids) = lagen(layer+1,3);
                cohesion(fourgrids) = lagen(layer+1,4);
                wet_weight(fourgrids) = lagen(layer+1,5);
            end    
        end 
    end 
    weight = weight(1:end-1);
    wet_weight = wet_weight(1:end-1);
    cohesion = cohesion(1:end-1); 
    %%%%%%%%%%%%%%%%%%%%%%%%%%%
    %effective soil weight: 
    for i = 1:length(weight)
        if waterlevel > z(i)
            effective_weight(i) = weight(i);
        else
            effective_weight(i) = wet_weight(i); % -10 does not work in clay layers, here the pressure distribution is not linear with the water depth
        end 
    end 
    
%% Wedge fan angel!!%%%%%%%%%%%%%%%%%%%%%%%%% very important for the pile-soil-pile interaction
    f_phimo = 1;  %f_phimob * phi = alpha 
    alpha = phi*f_phimo;                                %horizontal wedge angle 
    %cohesive layers do have a mobilized angle greater than 0 deg. (Gabr et al., 1990
    alpha(alpha==0) = 15 ; % EXAMPLE OF 15 DEGREES IS USED!!!!
    beta = 45 + alpha./2;                         %vertical wedge angle 
    alpha = flip(alpha);                        %flip both systems
    beta = flip(beta);
     
    Malpha = NaN*ones(length(z),length(z));     %create matrix for the grid
    Mbeta = NaN*ones(length(z),length(z));
    for fourgrids = 1:length(z)
        for j = 1:length(z)
            Malpha(1:end+1-fourgrids,fourgrids) = alpha(fourgrids:end);
            Mbeta(1:end+1-fourgrids,fourgrids) = beta(fourgrids:end);
        end 
    end
    px(:,1) = x_coordinate_pile;                %start coordinate of the pile in x direction 
    py(:,1) = y_coordinate_pile +0.5*D;         %start coordinate of the pile in y direction 
    for fourgrids = 1:length(z)
        for j = 1:length(z)-fourgrids
            px(fourgrids,j+1) = px(fourgrids,j) - tan(Mbeta(fourgrids,j)/180*pi)*dz;  %$ hier moet die beta vanaf dz lopen
            py(fourgrids,j+1) = py(fourgrids,j) + tan(Malpha(fourgrids,j)/180*pi)*dz; %% hier moet die alpha vanaf dz lopen      
        end 
    end 
    pyl = y_coordinate_pile-(py-y_coordinate_pile);       %pile is symetric  
    
    for fourgrids = 1:length(z)
        for j = 1:length(z)
           
            Z(fourgrids,j) = z(fourgrids)-j*dz+dz ;
            Z(fourgrids,fourgrids+1:end) = NaN;
            Z(fourgrids,fourgrids+1) = Z(fourgrids,fourgrids);
            Z(fourgrids,(n-1)) = z(fourgrids); 
            Z(fourgrids,(n))=Z(fourgrids,(n-1)) ;
            Z(:,length(z)+2:2*length(z)+1) = Z(:,1:length(z));
            
            X(length(z)-fourgrids+1,j) = px(fourgrids,j);
            Y(length(z)-fourgrids+1,j) = py(fourgrids,j);

            X(length(z)-fourgrids+1,j+length(z)+1) = px(fourgrids,j);
            Y(length(z)-fourgrids+1,j+length(z)+1) = pyl(fourgrids,j);

            Y(:,end-1) = flip(Y(length(z),1:length(z)));
            Y(:,end)= flip(Y(length(z),length(z)+2:1+2*length(z)));

            X(:,end-1) = flip(X(length(z),1:length(z)));
            X(:,end)= flip(X(length(z),1:length(z)));
        end
    end 
%% toprow
    for k = 1:length(z)-1
        X(k,1+k) = X(k,k);
        X(k,2+k+length(z)) = X(k,k);
        Y(k,1+k) = Y(k,k);
        Y(k,2+k+length(z)) = Y(k,k+1+length(z));
    end 
    
    %pile information 
    n_pile_grids = 24;
    zp = [z]';

    [Xpile,Ypile] = cylinder(0.5*pile_input.D ,n_pile_grids);
    Xpile = ones(length(zp),n_pile_grids+1).*Xpile(1,:)+pile_input.x_coordinate; 
    Ypile = ones(length(zp),n_pile_grids+1).*Ypile(1,:)+pile_input.y_coordinate; 
    Zpile = repmat(zp,1,n_pile_grids+1);
    
    %% Poly sections (z)
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% ([X],[Y]) for multi cell polyshapes%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    xp = NaN*zeros(length(z)-1,4,length(z)-1);            %%cross sectional points #4 per row
    yp = NaN*zeros(length(z)-1,4,length(z)-1);            %%cross sectional points #4 per row

    for fourgrids = 1:length(z)-1
        for depth = 0:length(z)-1-fourgrids
        xp(fourgrids,:,depth+1) = [X(length(z)+1-fourgrids,length(z)+1-fourgrids-depth) X(length(z)-1+1-fourgrids,length(z)-1+1-fourgrids-depth) X(length(z)-1+1-fourgrids,end-4+1-fourgrids-depth) X(length(z)+1-fourgrids,end-3+1-fourgrids-depth)];
        yp(fourgrids,:,depth+1) = [Y(length(z)+1-fourgrids,length(z)+1-fourgrids-depth) Y(length(z)-1+1-fourgrids,length(z)-1+1-fourgrids-depth) Y(length(z)-1+1-fourgrids,end-4+1-fourgrids-depth) Y(length(z)+1-fourgrids,end-3+1-fourgrids-depth)];
        end
    end
    minboundx = xp(1,1,1); 
    maxboundx = xp(1,2,end);
    minboundy = - pile_input.center2center_y/2;
    maxboundy =   pile_input.center2center_y/2;
    minboundyy = yp(1,4,1);
    maxboundyy = yp(1,1,1);
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% slope cropping polyshapes%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
                %---------/------PILE%%%%%
                %%%------/-------PILE%%%%%
                %%%%%%--/--------PILE%%%%%
                %%%%%%%/%%%%-----PILE%%%%%
                %%%%%%/%%%%%%%---PILE%%%%%
                %%%%%/%%%%%%%%%%%PILE%%%%%

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    xhelling = (x_coordinate_pile - (z(1:end-1) - top_pile_in_soil +0.000000000001)/helling);  %% CHANGED THIS 
    for slope = 1:length(xhelling) 
        if xhelling(slope) <  minboundx
            xhelling(slope) = minboundx; %to avoid large polygons, limit the subtraction   
            xhelling(slope) = flip(xhelling(slope)); 
        end 
        slopecorrect_poly(slope) = polyshape([xhelling(slope),xhelling(slope),minboundx-dz,minboundx-dz],[minboundyy,maxboundyy,maxboundyy,minboundyy]); 
    end 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Multi cell poly shapes%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    cell_multi_xp = num2cell(xp, [1 2]); %keep dimension 1 and 2 together
    nonanmulti_xp = cellfun(@(m) m(~any(isnan(m), 2), :), cell_multi_xp, 'UniformOutput', false);
    cell_multi_yp = num2cell(yp, [1 2]); %keep dimension 1 and 2 together
    nonanmulti_yp = cellfun(@(m) m(~any(isnan(m), 2), :), cell_multi_yp, 'UniformOutput', false);
    for j = 1:length(z)-1
        for i = 1:length(z)-j
            x_multi_poly(j,i) = {nonanmulti_xp{j}(i,:)};%(1:5)
            y_multi_poly(j,i) = {nonanmulti_yp{j}(i,:)};%(1:5)                       
            Total_poly_multi_cell(j,i) = polyshape(x_multi_poly(j,i),y_multi_poly(j,i),'Simplify',false);
            Cropped_poly_multi_cell(j,i) = subtract(Total_poly_multi_cell(j,i),slopecorrect_poly(j));
        end 
    end 


    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%contour of multi cell polyshape + pile shape%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    %singlepoly layer(z) + pile polyarea (the wedge surface area + pile area of at each section at depth Z) 
    for i = 1:length(z)-1
        X_poly(i,:) = {[squeeze(xp(:,4,i))' Xpile(i,n_pile_grids/4*3+1:end) Xpile(i,2:n_pile_grids/4+1)  flip(squeeze(xp(:,1,i))')]}; 
        Y_poly(i,:) = {[squeeze(yp(:,4,i))' Ypile(i,n_pile_grids/4*3+1:end) Ypile(i,2:n_pile_grids/4+1)  flip(squeeze(yp(:,1,i))')]};
        X_poly{i,:} = X_poly{i,:}(~isnan(X_poly{i,:})); 
        Y_poly{i,:} = Y_poly{i,:}(~isnan(Y_poly{i,:})); 
        Total_poly_cell(i) = polyshape(X_poly(i,:),Y_poly(i,:),'Simplify',false); 
        
        Total_poly_cell_negatiefY(i) = polyshape(X_poly(i,:),{Y_poly{i,:}-pile_input.center2center_y},'Simplify',false); 
        Total_poly_cell_positiefY(i) = polyshape(X_poly(i,:),{Y_poly{i,:}+pile_input.center2center_y},'Simplify',false); 
        Total_poly_cell_sidepilesY(i) = union(Total_poly_cell_negatiefY(i), Total_poly_cell_positiefY(i) );
        sidepiles_boundedY(i) = subtract(Total_poly_cell_sidepilesY(i),polyshape([minboundx maxboundx maxboundx minboundx],[minboundy minboundy maxboundy maxboundy]));      
    end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% create stucture %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    pile_output.grid.X = X;
    pile_output.grid.Y = Y;
    pile_output.grid.Z = Z;
    pile_output.pilegrid.X = Xpile;
    pile_output.pilegrid.Y = Ypile;
    pile_output.pilegrid.Z = Zpile;
    pile_output.grid.dz = dz;
    pile_output.grid.z = z; 
    pile_output.discrete_soil_info.phi = phi;
    pile_output.discrete_soil_info.cohesion(:,1) =cohesion;
    pile_output.discrete_soil_info.weight(:,1) = weight; 
    pile_output.discrete_soil_info.wet_weight(:,1) = wet_weight; 
    pile_output.discrete_soil_info.effective_weight(:,1) = effective_weight; 
    
    pile_output.poly.xp = xp;
    pile_output.poly.yp = yp;
    pile_output.poly.Total_poly_multi_cell = Total_poly_multi_cell; 
    pile_output.total_poly.Total_poly_cell = Total_poly_cell;
    pile_output.total_poly.sidepiles_boundedY = sidepiles_boundedY; 
    pile_output.poly.Cropped_multi = Cropped_poly_multi_cell; 
    
end
